summaryrefslogtreecommitdiff
path: root/libs/libcurl/src/transfer.h
diff options
context:
space:
mode:
Diffstat (limited to 'libs/libcurl/src/transfer.h')
-rw-r--r--libs/libcurl/src/transfer.h7
1 files changed, 3 insertions, 4 deletions
diff --git a/libs/libcurl/src/transfer.h b/libs/libcurl/src/transfer.h
index 75ffc23e31..26a17568bb 100644
--- a/libs/libcurl/src/transfer.h
+++ b/libs/libcurl/src/transfer.h
@@ -42,8 +42,6 @@ typedef enum {
FOLLOW_REDIR /* a full true redirect */
} followtype;
-CURLcode Curl_follow(struct Curl_easy *data, char *newurl,
- followtype type);
CURLcode Curl_sendrecv(struct Curl_easy *data, struct curltime *nowp);
int Curl_single_getsock(struct Curl_easy *data,
struct connectdata *conn, curl_socket_t *socks);
@@ -100,12 +98,13 @@ void Curl_xfer_setup1(struct Curl_easy *data,
* the amount to receive or -1 if unknown. With `shutdown` being
* set, the transfer is only allowed to either send OR receive
* and the socket 2 connection will be shutdown at the end of
* the transfer. An unclean shutdown will fail the transfer.
*/
void Curl_xfer_setup2(struct Curl_easy *data,
int send_recv,
curl_off_t recv_size,
- bool shutdown);
+ bool shutdown, bool shutdown_err_ignore);
/**
* Multi has set transfer to DONE. Last chance to trigger
@@ -100,12 +98,13 @@ void Curl_xfer_setup1(struct Curl_easy *data,
* set, the transfer is only allowed to either send OR receive
* and the socket 2 connection will be shutdown at the end of
- * the transfer. An unclean shutdown will fail the transfer.
+ * the transfer. An unclean shutdown will fail the transfer
+ * unless `shutdown_err_ignore` is TRUE.
*/
void Curl_xfer_setup2(struct Curl_easy *data,